@@ -72,6 +72,7 @@ extend = {extension.diagram(fit ,...)}
 #code adapted from John Fox
     segments=51
     angles <- (0:segments) * 2 * pi/segments
+    angles <- c(angles,NA)   #this allows us to draw multiple ellipses
     unit.circle <- cbind(cos(angles), sin(angles))
     xrange = (xlim[2] - xlim[1])
     yrange = (ylim[2] - ylim[1])
@@ -83,6 +84,24 @@ extend = {extension.diagram(fit ,...)}
    if(draw) lines(ellipse, ...)
     return(xs)
 }
+
+#added to allow for fast drawing of multiple ellipses in fa.diagram and bassAckward diagram
+dia.multi.ellipse <-  function(x, y = NULL, labels = NULL, cex = 1,e.size=.4,xlim=c(0,1),ylim=c(0,1),draw=TRUE, ...) {
+ segments=51
+    text(x=x, y = y, labels = labels,cex = cex, ...)
+    angles <- (0:segments) * 2 * pi/segments
+    angles <- c(angles,NA)   #this allows us to draw multiple ellipses
+    unit.circle <- cbind(cos(angles), sin(angles))
+    xrange = (xlim[2] - xlim[1])
+    yrange = (ylim[2] - ylim[1])
+    xs <- e.size * xrange
+   xs  <- max(strwidth(labels,units="user"))*.55  #make the radius slightly bigger than .5 label
+    ys <- max(strheight(labels,units="user"))  #*.55
+    ellipse <- unit.circle 
+     ellipsex <- rep(x,each=(segments + 2)) + unit.circle[,1] * xs
+     ellipsey <- rep(y,each=(segments + 2))  + unit.circle[,2] *ys
+      lines(ellipsex,ellipsey)
+}
        
 "dia.triangle" <- function(x, y = NULL, labels =NULL,  cex = 1, xlim=c(0,1),ylim=c(0,1),...) {
      text(x=x, y = y, labels = labels,  cex = cex,   ...)
@@ -378,9 +397,9 @@ text(x= textvalues[,1],y = textvalues[,2],labels=textvalues[,3])
 "multi.arrow" <- function(arrows.list,...){
  tv <- matrix(unlist(arrows.list),byrow=TRUE,ncol=21)
    #cname<- colnames(tv)
-   tv  <- data.frame(tv)
+   tv  <- data.frame(tv,stringsAsFactors=FALSE)
    tv[,c(1:2,4:19)] <- nchar2numeric(tv[,c(1:2,4:19)])
-   if(nchar(tv[1,21]) ==1) tv[,21] <- as.numeric(tv[,21 ]) #sometimes this is "solid", sometimes "1"
+   if(nchar(as.vector(tv[1,21])) ==1) tv[,21] <- as.numeric(tv[,21 ]) #sometimes this is "solid", sometimes "1"  #the as.vector gets around a problem in R 3.6
    #colnames(tv) <- cname
   textlocation <- tv[,1:5]
   #colnames(textlocation) <- c("x","y","labels","pos","cex")
