@@ -62,8 +62,8 @@ if(NROW(grp) > 1) { byGroup <- TRUE
    y.sd <-  by(y, grp, function (xx) sd(xx, na.rm=TRUE))
     x.n <-by(x,grp,function(xx) sum(!is.na(xx)))
     y.n   <-by(y,grp,function(xx) sum(!is.na(xx)))
-    x.d <-  (x.means[2]-x.means[1])/sqrt(((x.sd[1]^2*x.n[1]+ x.sd[2]^2* x.n[2]))/(x.n[1] + x.n[2])) 
-   y.d <-  (y.means[2]-y.means[1])/sqrt(((y.sd[1]^2*y.n[1]+ y.sd[2]^2* y.n[2]))/(y.n[1] + y.n[2])) 
+    x.d <-  (x.means[2]-x.means[1])/sqrt(((x.sd[1]^2*(x.n[1]-1))+ x.sd[2]^2* (x.n[2]-1))/(x.n[1] + x.n[2]))   #changed to n-1 7/29/21 
+   y.d <-  (y.means[2]-y.means[1])/sqrt(((y.sd[1]^2*(y.n[1]-1)+ y.sd[2]^2* (y.n[2]-2)))/(y.n[1] + y.n[2])) 
    
    R.inv <- solve(sb$rwg)
    dist <- c(x.d,y.d)
@@ -79,7 +79,9 @@ if(NROW(grp) > 1) { byGroup <- TRUE
   
   dx.max <- max(dx.max, dx[[i]]$y)
   dy.max <- max(dy.max, dy[[i]]$y)}
-} else {byGroup <- FALSE}
+} else {byGroup <- FALSE
+      x.means <- y.means <-x.d <- y.d<- stats<- NA   #give them a value so we have something to report in the results
+      }
 
                                    
 xrange <- range(x,na.rm=TRUE)
@@ -256,13 +258,16 @@ txt <- paste0("r = ", round(r,digits),"\n")
   plot(1,1,type="n",axes=FALSE)
   if(!is.null(Md) ) {
   
-  txt <- paste0("D = ",round(Md,2),"\n")
+  txt <- paste0("D = ",sprintf("%.2f",round(Md,2)),"\n")
   if(missing(cex.cor)) {cex <- 0.75/strwidth(txt)} else {cex <- cex.cor}
   text(1,1,txt,cex=cex)
   #text(1,.8,paste0("r wg =",round(sb$rwg[1,2],2) ),cex=cex)
   }
   }
+  
+  result <- list(x.means=x.means,y.means=y.means,x.d=x.d, y.d = y.d,stats=sb)
 par(old.par)
+invisible(result)
 }
 #version of March 7, 2011
 #revised Sept 7, 2013 to include method option in cor
