@@ -68,7 +68,7 @@ dev.off()
 ###################################################
 ### code chunk number 9: affect1
 ###################################################
-keys <- make.keys(msq[1:75],list(
+keys <- list(
 EA = c("active", "energetic", "vigorous", "wakeful", "wide.awake", "full.of.pep",
        "lively", "-sleepy", "-tired", "-drowsy"),
  TA =c("intense", "jittery", "fearful", "tense", "clutched.up", "-quiet", "-still", 
@@ -76,8 +76,8 @@ EA = c("active", "energetic", "vigorous", "wakeful", "wide.awake", "full.of.pep"
 PA =c("active", "excited", "strong", "inspired", "determined", "attentive", 
           "interested", "enthusiastic", "proud", "alert"),
 NAf =c("jittery", "nervous", "scared", "afraid", "guilty", "ashamed", "distressed",  
-         "upset", "hostile", "irritable" )) )
-scores <- scoreItems(keys,msq[,1:75])
+         "upset", "hostile", "irritable" )) 
+scores <- scoreItems(keys,psychTools::msq[,1:75])
 #png('msq.png')
 # pairs.panels(scores$scores,smoother=TRUE,
 #  main ="Density distributions of four measures of affect" )
